RelativePathResolver

Struct RelativePathResolver 

pub struct RelativePathResolver(/* private fields */);
The default import resolver, which resolves everything relative to one initial path

Implementations

Source

impl RelativePathResolver

pub fn siblings_with(file: impl AsRef<Path>) -> AstResult<Self>

A convenience function for creating based on a specific path, such as the main.ccs

Note that the source should be an absolute path, but this will then allow for resolving relative to the parent directory of the given file.

If the source isn’t absolute, it will go relative to the current working directory. However, subsequent resolvers created through ImportResolver::new_context will be absolute.